// Copyright (c) 2012-2013 The PPCoin developers
// Copyright (c) 2020-2022 The Cosanta Core developers
// Distributed under the MIT/X11 software license, see the accompanying
// file COPYING or http://www.opensource.org/licenses/mit-license.php.
#ifndef BITCOIN_KERNEL_H
#define BITCOIN_KERNEL_H

#include "chain.h"
#include "streams.h"
#include "util.h"


	// MODIFIER_INTERVAL: time to elapse before new modifier is computed
	static const unsigned int MODIFIER_INTERVAL = 60; 
	static const unsigned int MODIFIER_INTERVAL_TESTNET = 60;
	extern unsigned int nModifierInterval;
	extern unsigned int getIntervalVersion(bool fTestNet);

	// MODIFIER_INTERVAL_RATIO:
	// ratio of group interval length between the last group and the first group
	static const int MODIFIER_INTERVAL_RATIO = 3;

	// Compute the hash modifier for proof-of-stake
	bool ComputeNextStakeModifier(const CBlockIndex* pindexPrev, uint64_t& nStakeModifier, bool& fGeneratedStakeModifier);

	// Check whether stake kernel meets hash target
	// Sets hashProofOfStake on success return
	uint256 stakeHash(unsigned int nTimeTx, CDataStream ss, unsigned int prevoutIndex, uint256 prevoutHash, unsigned int nTimeBlockFrom);
	bool stakeTargetHit(uint256 hashProofOfStake, int64_t nValueIn, uint256 bnTargetPerCoinDay);
	bool CheckStakeKernelHash(unsigned int nBits, const CBlock blockFrom, const CTransaction txPrev, const COutPoint prevout, unsigned int& nTimeTx, unsigned int nHashDrift, bool fCheck, uint256& hashProofOfStake, bool fPrintProofOfStake = false);

	// Check kernel hash target and coinstake signature
	// Sets hashProofOfStake on success return
	bool CheckProofOfStake(const CTransaction& tx, unsigned int nTxTime, unsigned int nBits, uint256& hashProofOfStake);

	// Check whether the coinstake timestamp meets protocol
	bool CheckCoinStakeTimestamp(int64_t nTimeBlock, int64_t nTimeTx);

	// Get stake modifier checksum
	unsigned int GetStakeModifierChecksum(const CBlockIndex* pindex);

	// Check stake modifier hard checkpoints
	bool CheckStakeModifierCheckpoints(int nHeight, unsigned int nStakeModifierChecksum);

	// Get time weight using supplied timestamps
	int64_t GetWeight(int64_t nIntervalBeginning, int64_t nIntervalEnd);

#endif // BITCOIN_KERNEL_H
